pub struct WalletOperatorAddressParams {}Expand description
control.wallet.operatorAddress params — none.
There is exactly one operator wallet per node, so there is nothing to scope the question by. Deliberately NOT an address-taking method: a caller cannot ask is THIS address the operator wallet by supplying a candidate, because a node answering yes/no about supplied addresses is an oracle for probing which addresses a machine controls.