pub struct CapsuleEntry {
pub capsule: String,
pub root: String,
pub size_bytes: u64,
pub last_used_unix_ms: u64,
}Expand description
One cached capsule of a store, as listed by the hosted-stores methods.
Fields
capsule: StringThe capsule reference (storeId:rootHash).
root: StringThe capsule root hash.
size_bytes: u64The capsule size on disk, in bytes.
last_used_unix_ms: u64When the capsule was last served, in unix milliseconds.